#ifndef CMD_SQUERY_H
#define CMD_SQUERY_H

__SWIRC_BEGIN_DECLS
void	cmd_squery(const char *) NONNULL;
__SWIRC_END_DECLS

#endif
